@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"errors"
 	"reflect"
 	"testing"
@@ -31,7 +32,7 @@ func Test_collectionsDiscoveryHandler(t *testing.T) {
 	tests := []struct {
 		name    string
 		args    args
-		want    interface{}
+		want    any
 		wantErr error
 	}{
 		{
@@ -78,7 +79,7 @@ func Test_collectionsDiscoveryHandler(t *testing.T) {
 				}
 			}
 
-			got, err := CollectionsDiscoveryHandler(tt.args.s, nil)
+			got, err := CollectionsDiscoveryHandler(context.Background(), tt.args.s, nil)
 			if !errors.Is(err, tt.wantErr) {
 				t.Errorf("collectionsDiscoveryHandler() error = %v, wantErr %v", err, tt.wantErr)
 
