@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"time"
@@ -28,7 +29,7 @@ import (
 
 // OplogStatsHandler
 // https://docs.mongodb.com/manual/reference/method/db.getReplicationInfo/index.html
-func OplogStatsHandler(s Session, _ map[string]string) (any, error) {
+func OplogStatsHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
 	var (
 		err             error
 		firstTs, lastTs int
@@ -36,13 +37,12 @@ func OplogStatsHandler(s Session, _ map[string]string) (any, error) {
 
 	localDb := s.DB("local")
 	findOptions := options.FindOne()
-	findOptions.SetMaxTime(time.Duration(s.GetMaxTimeMS()) * time.Millisecond)
 
 	for _, collection := range []string{
 		"oplog.rs",    // the capped collection that holds the oplog for Replica Set Members
 		"oplog.$main", // oplog for the master-slave configuration
 	} {
-		firstTs, lastTs, err = getTS(collection, localDb, findOptions)
+		firstTs, lastTs, err = getTS(ctx, collection, localDb, findOptions)
 		if err != nil {
 			if !errors.Is(err, mongo.ErrNoDocuments) {
 				return nil, zbxerr.ErrorCannotFetchData.Wrap(err)
@@ -69,20 +69,21 @@ func OplogStatsHandler(s Session, _ map[string]string) (any, error) {
 }
 
 func getTS(
+	ctx context.Context,
 	collection string,
 	localDb Database,
 	findOptions *options.FindOneOptions,
 ) (int, int, error) {
 	findOptions.SetSort(bson.D{{Key: sortNatural, Value: -1}})
 
-	firstTs, err := getOplogStats(localDb, collection, findOptions)
+	firstTs, err := getOplogStats(ctx, localDb, collection, findOptions)
 	if err != nil {
 		return 0, 0, err
 	}
 
 	findOptions.SetSort(bson.D{{Key: sortNatural, Value: 1}})
 
-	lastTs, err := getOplogStats(localDb, collection, findOptions)
+	lastTs, err := getOplogStats(ctx, localDb, collection, findOptions)
 	if err != nil {
 		return 0, 0, err
 	}
@@ -91,13 +92,14 @@ func getTS(
 }
 
 func getOplogStats(
+	ctx context.Context,
 	db Database,
 	collection string,
 	opt *options.FindOneOptions,
 ) (int, error) {
 	var result primitive.D
 
-	err := db.C(collection).FindOne(bson.M{"ts": bson.M{"$exists": true}}, opt).
+	err := db.C(collection).FindOne(ctx, bson.M{"ts": bson.M{"$exists": true}}, opt).
 		GetSingle(&result)
 	if err != nil {
 		return 0, err
