@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 
 	"go.mongodb.org/mongo-driver/bson"
@@ -23,9 +24,10 @@ import (
 
 // ReplSetConfigHandler
 // https://docs.mongodb.com/manual/reference/command/replSetGetConfig/index.html
-func ReplSetConfigHandler(s Session, _ map[string]string) (interface{}, error) {
+func ReplSetConfigHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
 	replSetGetConfig := &bson.M{}
 	err := s.DB("admin").Run(
+		ctx,
 		&bson.D{
 			{
 				Key:   "replSetGetConfig",
@@ -35,10 +37,6 @@ func ReplSetConfigHandler(s Session, _ map[string]string) (interface{}, error) {
 				Key:   "commitmentStatus",
 				Value: true,
 			},
-			{
-				Key:   "maxTimeMS",
-				Value: s.GetMaxTimeMS(),
-			},
 		},
 		replSetGetConfig,
 	)
