@@ -15,16 +15,18 @@
 package handlers
 
 import (
+	"context"
+
 	"go.mongodb.org/mongo-driver/bson"
 	"golang.zabbix.com/sdk/zbxerr"
 )
 
 // VersionHandler executes 'buildInfo' command extracting and returning version
 // info from the response.
-func VersionHandler(s Session, _ map[string]string) (any, error) {
+func VersionHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
 	buildInfo := bson.M{}
 
-	err := s.DB("admin").Run(&bson.D{{Key: "buildInfo", Value: 1}}, &buildInfo)
+	err := s.DB("admin").Run(ctx, &bson.D{{Key: "buildInfo", Value: 1}}, &buildInfo)
 	if err != nil {
 		return nil, zbxerr.New("failed to run buildInfo command").Wrap(err)
 	}
